``baseplate.lib.file_watcher``
==============================

.. automodule:: baseplate.lib.file_watcher

.. autoclass:: FileWatcher
   :members:


Exceptions
----------

.. autoexception:: WatchedFileNotAvailableError

Testing
-------

.. autoclass:: baseplate.testing.lib.file_watcher.FakeFileWatcher
